<?php
namespace ahura\inc\widgets;

// Block direct access to the main plugin file.
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

use ahura\app\mw_assets;
use ahura\app\Post_Meta;
use Elementor\Controls_Manager;

class post_carousel8 extends \ahura\app\elementor\Elementor_Widget_Base {
    /**
     * @param array $data
     * @param null $args
     */
    public function __construct($data = [], $args = null)
    {
        parent::__construct($data, $args);
        mw_assets::register_swiper_assets();
        mw_assets::register_script('post_carousel8_js', mw_assets::get_js('elementor.post_carousel8'));
    }

    public function __register_assets()
    {
        $this->register_elementor_style('post_carousel8_css', mw_assets::get_css('elementor.post_carousel8'));
    }

    public function get_script_depends()
    {
        return [mw_assets::get_handle_name('post_carousel8_js')];
    }

    public function get_name() {
        return 'post_carousel8';
    }

    public function get_title() {
        return __( 'Post Carousel 8', 'ahura' );
    }

    public function get_icon() {
        return 'eicon-posts-carousel';
    }

    public function get_categories() {
        return [ 'ahuraelements', 'ahura_posts' ];
    }
    function get_keywords()
    {
        return ['ahura', 'post_carousel8', 'postcarousel8', esc_html__( 'Post Carousel 8' , 'ahura')];
    }

    public function register_controls() {
        $this->start_controls_section(
            'content_section',
            [
                'label' => __( 'Content', 'ahura' ),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'show_type',
            [
                'label'    => __( 'Show Type', 'ahura' ),
                'type'     => \Elementor\Controls_Manager::SELECT,
                'options'  => [
                    'category' => __('Categories', 'ahura'),
                    'custom' => __('Select Post', 'ahura'),
                ],
                'label_block' => true,
                'default' => 'category'
            ]
        );

        $categories = get_categories();
        $cats       = array();
        foreach ( $categories as $category ) {
            $cats[ $category->term_id ] = $category->name;
        }
        $default = key($cats);
        $this->add_control(
            'catsid',
            [
                'label'    => __( 'Categories', 'ahura' ),
                'type'     => \Elementor\Controls_Manager::SELECT2,
                'options'  => $cats,
                'label_block' => true,
                'multiple' => true,
                'default'	=>	$default,
                'condition' => ['show_type' => 'category']
            ]
        );

        $posts_list = [];
        $posts = get_posts(['numberposts' => -1]);

        if(!empty($posts)){
            foreach ($posts as $post){
                $posts_list[$post->ID] = $post->post_title;
            }
        }

        $this->add_control(
            'selected_posts',
            [
                'label' => __('Posts', 'ahura'),
                'label_block' => true,
                'type' => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'options' => $posts_list,
                'default' => key($posts_list),
                'condition' => ['show_type' => 'custom']
            ]
        );

        $this->add_control(
            'count',
            [
                'label'      => __( 'Number of posts', 'ahura' ),
                'type'       => \Elementor\Controls_Manager::NUMBER,
                'default'    => 8,
                'condition' => ['show_type!' => 'custom']
            ]
        );

        $this->add_control(
            'post_order',
            [
                'label' => __('Sort', 'ahura'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'default' => 'DESC',
                'options' => [
                    'ASC' => [
                        'title' => __('Ascending', 'ahura'),
                        'icon' => 'eicon-sort-up'
                    ],
                    'DESC' => [
                        'title' => __('Descending', 'ahura'),
                        'icon' => 'eicon-sort-down'
                    ],
                ],
                'toggle' => true
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Image_Size::get_type(),
            [
                'name' => 'item_cover',
                'default' => 'full',
            ]
        );

        $this->add_responsive_control(
            'object_fit',
            [
                'label' => esc_html__( 'Aspect ratio', 'ahura' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'cover',
                'options' => [
                    'fill' => esc_html__( 'Default', 'ahura' ),
                    'contain' => esc_html__( 'Contain', 'ahura' ),
                    'cover'  => esc_html__( 'Cover', 'ahura' ),
                ],
                'selectors' => [
                    '{{WRAPPER}} .post-cover img' => 'object-fit: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'hover_icon_options',
            [
                'label' => esc_html__( 'Hover Mode Icon', 'ahura' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'show_hover_icon',
            [
                'label' => esc_html__('Show Hover Icon', 'ahura'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'ahura'),
                'label_off' => esc_html__('Hide', 'ahura'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'hover_icon',
            [
                'label' => esc_html__( 'Icon', 'ahura' ),
                'type' => \Elementor\Controls_Manager::ICONS,
                'default' => [
                    'value' => 'fas fa-play',
                    'library' => 'fa-solid',
                ],
                'condition' => ['show_hover_icon' => 'yes']
            ]
        );

        $this->add_control(
            'slider_options',
            [
                'label' => esc_html__( 'Slider', 'ahura' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'slides_per_view',
            [
                'label'      => __( 'Slides Per View', 'ahura' ),
                'type'       => \Elementor\Controls_Manager::NUMBER,
                'default'    => 3
            ]
        );

        $this->add_control(
            'slides_margin',
            [
                'label'      => __( 'Slides Spacing', 'ahura' ),
                'type'       => \Elementor\Controls_Manager::NUMBER,
                'default'    => 10
            ]
        );

        $this->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'ahura'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'ahura'),
                'label_off' => esc_html__('Hide', 'ahura'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'show_slider_btn',
            [
                'label' => esc_html__('Slider Button', 'ahura'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Show', 'ahura'),
                'label_off' => esc_html__('Hide', 'ahura'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'use_observer_slider',
            [
                'label' => esc_html__('Inner Slider', 'ahura'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'ahura'),
                'label_off' => esc_html__('No', 'ahura'),
                'return_value' => 'yes',
                'default' => 'yes',
                'description' => __('If you use the slider internally (tab, ...) and its display is not direct, be sure to activate this option.', 'ahura')
            ]
        );

        $this->end_controls_section();
        /**
         *
         *
         * Styles
         *
         *
         */
        $this->start_controls_section(
            'items_styles',
            [
                'label' => __( 'Items', 'ahura' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'box_img_height',
            [
                'label' => esc_html__('Item Height', 'ahura'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['px', 'em', 'rem', '%'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                    'em' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                    'rem' => [
                        'min' => 0,
                        'max' => 1000,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 580
                ],
                'devices' => ['desktop', 'tablet', 'mobile'],
                'selectors' => [
                    '{{WRAPPER}} .post-item img' => 'height: {{SIZE}}{{UNIT}}',
                ]
            ]
        );

        $this->add_control(
            'item_radius',
            [
                'label' => esc_html__( 'Border Radius', 'ahura' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em', 'rem', 'custom' ],
                'selectors' => [
                    '{{WRAPPER}} .post-item img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'item_border',
                'selector' => '{{WRAPPER}} .post-item img',
            ]
        );

        $this->add_control('hr1', ['type' => \Elementor\Controls_Manager::DIVIDER]);

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Title Color', 'ahura' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#333',
                'selectors' => [
                    '{{WRAPPER}} .post-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => esc_html__('Title Typography', 'ahura'),
                'selector' => '{{WRAPPER}} .post-title',
                'fields_options' => [
                    'typography' => ['default' => 'yes'],
                    'font_weight' => ['default' => '600'],
                    'font_size' => [
                        'default' => [
                            'unit' => 'px',
                            'size' => '25',
                        ]
                    ]
                ]
            ]
        );

        $this->add_control(
            'hover_icon_style_options',
            [
                'label' => esc_html__( 'Hover Mode Icon', 'ahura' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'hover_icon_color',
            [
                'label' => esc_html__( 'Icon Color', 'ahura' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#fff',
                'selectors' => [
                    '{{WRAPPER}} .post-item .icon-button i' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .post-item .icon-button :is(svg, path)' => 'fill: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'hover_icon_bg',
                'selector' => '{{WRAPPER}} .post-item .icon-button',
                'types' => ['classic', 'gradient'],
                'exclude' => ['image'],
                'fields_options' => [
                    'background' => [
                        'default' => 'classic'
                    ],
                    'color' => [
                        'default' => '#000000bf'
                    ],
                ]
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'hover_icon_shadow',
                'label' => esc_html__('Box Shadow', 'ahura'),
                'selector' => '{{WRAPPER}} .post-item .icon-button',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'box_navigation_style',
            [
                'label' => esc_html__('Navigation', 'ahura'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->start_controls_tabs('slider_nav_style_tabs');
        $this->start_controls_tab('slider_nav_style_normal_tab', ['label' => esc_html__( 'Normal', 'ahura' )]);

        $this->add_control(
            'box_nav_color',
            [
                'label' => esc_html__('Color', 'ahura'),
                'type' => Controls_Manager::COLOR,
                'default' => '#333',
                'selectors' => [
                    '{{WRAPPER}} .swiper-button-next, {{WRAPPER}} .swiper-button-prev' => 'color: {{VALUE}}',
                ]
            ]
        );

        $this->add_control(
            'box_nav_bg_color',
            [
                'label' => esc_html__('Background Color', 'ahura'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-button-next, {{WRAPPER}} .swiper-button-prev' => 'background-color: {{VALUE}}',
                ]
            ]
        );

        $this->end_controls_tab();
        $this->start_controls_tab('slider_nav_style_hover_tab', ['label' => esc_html__( 'Hover', 'ahura' )]);

        $this->add_control(
            'box_nav_color_hover',
            [
                'label' => esc_html__('Color', 'ahura'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-button-next:hover, {{WRAPPER}} .swiper-button-prev:hover' => 'color: {{VALUE}}',
                ]
            ]
        );

        $this->add_control(
            'box_nav_bg_color_hover',
            [
                'label' => esc_html__('Background Color', 'ahura'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .swiper-button-next:hover, {{WRAPPER}} .swiper-button-prev:hover' => 'background-color: {{VALUE}}',
                ]
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();
    }

    public function render() {
        $settings = $this->get_settings_for_display();
        $wid = $this->get_id();
        $show_slides_nav = $settings['show_slider_btn'] == 'yes';
        $show_type = $settings['show_type'];

        $sliderData = [
            'widgetID' => $wid,
            'autoplay' => $settings['autoplay'] == 'yes',
            'slidesPerView' => $settings['slides_per_view'],
            'margin' => $settings['slides_margin'],
            'observer' => $settings['use_observer_slider'] == 'yes'
        ];

        $posts_args = array(
            'posts_per_page' => $settings['count'],
            'order' => $settings['post_order']
        );

        if($show_type == 'category'){
            $posts_args['cat'] = $settings['catsid'];
        }

        if($show_type == 'custom'){
            $selected_posts = $settings['selected_posts'];
            $selected_posts = ahura_sanitize_posts((!is_array($selected_posts) ? [$selected_posts] : $selected_posts));
            $posts_args['post__in'] = $selected_posts;
            if($selected_posts){
                unset($posts_args['posts_per_page']);
            } else {
                $posts_args['posts_per_page'] = 3;
            }
        }

        $posts = new \WP_Query($posts_args);
        if ( $posts->have_posts() ) : ?>
            <div class="ah-slider-post-8 post-carousel8">
                <div dir="<?php echo is_rtl() ? 'rtl' : 'ltr' ?>" class="swiper posts-carousel" data-slider='<?php echo json_encode($sliderData) ?>'>
                    <div class="swiper-wrapper">
                        <?php while ( $posts->have_posts() ) : $posts->the_post(); ?>
                            <div class="swiper-slide">
                                <div class="post-item">
                                    <a href="<?php the_permalink(); ?>">
                                        <div class="post-cover">
                                            <?php the_post_thumbnail() ?>
                                            <div class="details">
                                                <?php
                                                if ($settings['show_hover_icon'] == 'yes'):
                                                    $hover_icon = $settings['hover_icon'];
                                                    ?>
                                                    <div class="icon-button-wrap">
                                                        <div class="icon-button">
                                                            <?php \Elementor\Icons_Manager::render_icon($hover_icon, [ 'aria-hidden' => 'true' ] ) ?>
                                                        </div>
                                                    </div>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                        <h2 class="post-title has-text"><?php the_title(); ?></h2>
                                    </a>
                                </div>
                            </div>
                        <?php endwhile; ?>
                    </div>
                    <?php if ($show_slides_nav): ?>
                        <div class="swiper-button-next"></div>
                        <div class="swiper-button-prev"></div>
                    <?php endif; ?>
                </div>
            </div>
            <?php wp_reset_postdata(); ?>
        <?php endif; ?>
        <div class="clear"></div>
        <?php
    }
}
